@@ -14,7 +14,7 @@
 #include "katebookmarkhandler.h"
 #include "katefileactions.h"
 
-#include <ktexteditor/document.h>
+#include <KTextEditor/Document>
 #include <ktexteditor/view.h>
 
 #include <KActionCollection>
@@ -28,7 +28,6 @@
 #include <KSharedConfig>
 #include <KToolBar>
 #include <KUrlNavigator>
-#include <kwidgetsaddons_version.h>
 
 #include <QAbstractItemView>
 #include <QAction>
@@ -478,5 +477,3 @@ void KateFileBrowser::setupActions()
     }
 }
 // END Protected
-
-#include "moc_katefilebrowser.cpp"
