@@ -63,6 +63,7 @@ struct LSPClientCompletionItem : public LSPCompletionItem {
     QString postfix;
     int start = 0;
     int len = 0;
+    bool m_docResolved = false;
 
     LSPClientCompletionItem(const LSPCompletionItem &item)
         : LSPCompletionItem(item)
@@ -99,8 +100,6 @@ struct LSPClientCompletionItem : public LSPCompletionItem {
  */
 class CompletionIcons : public QObject
 {
-    Q_OBJECT
-
 public:
     CompletionIcons()
         : QObject(KTextEditor::Editor::instance())
@@ -181,8 +180,6 @@ static bool compare_match(const LSPCompletionItem &a, const LSPCompletionItem &b
 
 class LSPClientCompletionImpl : public LSPClientCompletion
 {
-    Q_OBJECT
-
     typedef LSPClientCompletionImpl self_type;
 
     std::shared_ptr<LSPClientServerManager> m_manager;
@@ -270,6 +267,26 @@ public:
         } else if (role == KTextEditor::CodeCompletionModel::IsExpandable) {
             return !match.documentation.value.isEmpty();
         } else if (role == KTextEditor::CodeCompletionModel::ExpandingWidget && !match.documentation.value.isEmpty()) {
+            if (m_server->capabilities().completionProvider.resolveProvider && !match.m_docResolved && !match.data.isNull()) {
+                QPersistentModelIndex pIndex = QPersistentModelIndex(index);
+                auto h = [this, pIndex](const LSPCompletionItem &c) {
+                    if (pIndex.isValid()) {
+                        auto self = const_cast<LSPClientCompletionImpl *>(this);
+                        QModelIndex i = QModelIndex(pIndex);
+                        // we only support resolving additionalTextEdits and documentation so only
+                        // update those fields
+                        self->m_matches[i.row()].documentation.value += c.documentation.value;
+                        self->m_matches[i.row()].additionalTextEdits = c.additionalTextEdits;
+                        self->m_matches[i.row()].m_docResolved = true;
+                        self->dataChanged(i, i, {KTextEditor::CodeCompletionModel::ExpandingWidget});
+                    }
+                };
+
+                m_server->documentCompletionResolve(match, this, h);
+                auto self = const_cast<LSPClientCompletionImpl *>(this);
+                self->m_matches[index.row()].m_docResolved = true;
+            }
+
             // probably plaintext, but let's show markdown as-is for now
             // FIXME better presentation of markdown
             return match.documentation.value;
@@ -308,7 +325,7 @@ public:
 
         // covers most already ...
         bool complete = CodeCompletionModelControllerInterface::shouldStartCompletion(view, insertedText, userInsertion, position);
-        QChar lastChar = insertedText.at(insertedText.count() - 1);
+        QChar lastChar = insertedText.at(insertedText.size() - 1);
 
         m_triggerSignature = false;
         complete = complete || m_triggersCompletion.contains(lastChar);
@@ -534,7 +551,7 @@ public:
             // (which takes care to use moving range, etc)
             if (!additionalTextEdits.isEmpty()) {
                 applyEdits(view->document(), nullptr, additionalTextEdits);
-            } else if (!item.data.isNull() && m_server->capabilities().completionProvider.resolveProvider) {
+            } else if (!item.m_docResolved && !item.data.isNull() && m_server->capabilities().completionProvider.resolveProvider) {
                 QPointer<KTextEditor::Document> doc = view->document();
                 auto h = [doc](const LSPCompletionItem &c) {
                     if (doc && !c.additionalTextEdits.isEmpty()) {
@@ -562,6 +579,3 @@ LSPClientCompletion *LSPClientCompletion::new_(std::shared_ptr<LSPClientServerMa
 {
     return new LSPClientCompletionImpl(std::move(manager));
 }
-
-#include "lspclientcompletion.moc"
-#include "moc_lspclientcompletion.cpp"
