@@ -28,6 +28,7 @@ LSPClientConfigPage::LSPClientConfigPage(QWidget *parent, LSPClientPlugin *plugi
 {
     ui = new Ui::LspConfigWidget();
     ui->setupUi(this);
+    ui->tabWidget->setDocumentMode(true);
 
     // fix-up our two text edits to be proper JSON file editors
     updateHighlighters();
@@ -284,5 +285,3 @@ void LSPClientConfigPage::showContextMenuAllowedBlocked(const QPoint &pos)
 
     myMenu.exec(ui->allowedAndBlockedServers->mapToGlobal(pos));
 }
-
-#include "moc_lspclientconfigpage.cpp"
