@@ -19,6 +19,8 @@
 #include <KPropertiesDialog>
 #include <KTerminalLauncherJob>
 #include <KTextEditor/Document>
+#include <KTextEditor/MainWindow>
+#include <KTextEditor/View>
 
 #include <QAction>
 #include <QApplication>
@@ -36,12 +38,13 @@
 #include <ktexteditor/application.h>
 #include <ktexteditor/editor.h>
 
-static QString getName(QWidget *parent)
+static QString getName(QWidget *parent, const QString &title)
 {
     QInputDialog dlg(parent);
+    dlg.setWindowTitle(title);
     dlg.setLabelText(i18n("Enter name:"));
-    dlg.setOkButtonText(i18n("Add"));
     dlg.setInputMode(QInputDialog::TextInput);
+    dlg.resize(400, dlg.height());
 
     int res = dlg.exec();
     bool suc = res == QDialog::Accepted;
@@ -51,6 +54,29 @@ static QString getName(QWidget *parent)
     return dlg.textValue();
 }
 
+static void onDeleteFile(const QModelIndex &index, const QString &path, KateProjectViewTree *parent)
+{
+    if (!index.isValid())
+        return;
+    const QPersistentModelIndex idx = index;
+    const QString title = i18n("Delete File");
+    const QString text = i18n("Do you want to delete the file '%1'?", path);
+    if (QMessageBox::Yes == QMessageBox::question(parent, title, text, QMessageBox::No | QMessageBox::Yes, QMessageBox::Yes)) {
+        if (!idx.isValid())
+            return;
+        const QList<KTextEditor::Document *> openDocuments = KTextEditor::Editor::instance()->application()->documents();
+
+        // if is open, close
+        for (auto doc : openDocuments) {
+            if (doc->url().adjusted(QUrl::RemoveScheme) == QUrl(path).adjusted(QUrl::RemoveScheme)) {
+                KTextEditor::Editor::instance()->application()->closeDocument(doc);
+                break;
+            }
+        }
+        parent->removeFile(idx, path);
+    }
+}
+
 void KateProjectTreeViewContextMenu::exec(const QString &filename, const QModelIndex &index, const QPoint &pos, KateProjectViewTree *parent)
 {
     /**
@@ -63,11 +89,13 @@ void KateProjectTreeViewContextMenu::exec(const QString &filename, const QModelI
      */
     QAction *copyAction = menu.addAction(QIcon::fromTheme(QStringLiteral("edit-copy-path")), i18n("Copy Location"));
 
+    const bool isRootDirectory = !index.isValid();
+
     QAction *addFile = nullptr;
     QAction *addFolder = nullptr;
-    if (index.data(KateProjectItem::TypeRole).toInt() == KateProjectItem::Directory) {
-        addFile = menu.addAction(QIcon::fromTheme(QStringLiteral("document-new")), i18n("Add File"));
-        addFolder = menu.addAction(QIcon::fromTheme(QStringLiteral("folder-new")), i18n("Add Folder"));
+    if (isRootDirectory || index.data(KateProjectItem::TypeRole).toInt() == KateProjectItem::Directory) {
+        addFile = menu.addAction(QIcon::fromTheme(QStringLiteral("document-new")), i18n("New File…"));
+        addFolder = menu.addAction(QIcon::fromTheme(QStringLiteral("folder-new")), i18n("New Folder…"));
     }
 
     // we can ATM only handle file renames
@@ -119,23 +147,17 @@ void KateProjectTreeViewContextMenu::exec(const QString &filename, const QModelI
         fileHistory = menu.addAction(i18n("Show Git History"));
     }
 
-    auto handleDeleteFile = [parent, index](const QString &path) {
-        // message box
-        const QString title = i18n("Delete File");
-        const QString text = i18n("Do you want to delete the file '%1'?", path);
-        if (QMessageBox::Yes == QMessageBox::question(parent, title, text, QMessageBox::No | QMessageBox::Yes, QMessageBox::Yes)) {
-            const QList<KTextEditor::Document *> openDocuments = KTextEditor::Editor::instance()->application()->documents();
-
-            // if is open, close
-            for (auto doc : openDocuments) {
-                if (doc->url().adjusted(QUrl::RemoveScheme) == QUrl(path).adjusted(QUrl::RemoveScheme)) {
-                    KTextEditor::Editor::instance()->application()->closeDocument(doc);
-                    break;
-                }
-            }
-            parent->removeFile(index, path);
+    auto externaltoolsplugin = parent->mainWindow()->pluginView(QStringLiteral("externaltoolsplugin"));
+    auto view = parent->mainWindow()->activeView();
+    auto doc = view ? view->document() : nullptr;
+    if (doc && externaltoolsplugin) {
+        QAction *a = nullptr;
+        QMetaObject::invokeMethod(externaltoolsplugin, "externalToolsForDocumentAction", Q_RETURN_ARG(QAction *, a), doc);
+        if (a) {
+            a->setParent(&menu);
+            menu.addAction(a);
         }
-    };
+    }
 
     /**
      * run menu and handle the triggered action
@@ -158,7 +180,7 @@ void KateProjectTreeViewContextMenu::exec(const QString &filename, const QModelI
         } else if (action == openContaingFolderAction) {
             KIO::highlightInFileManager({url});
         } else if (fileDelete && action == fileDelete) {
-            handleDeleteFile(filename);
+            onDeleteFile(index, filename, parent);
         } else if (action == filePropertiesAction) {
             // code copied and adapted from frameworks/kio/src/filewidgets/knewfilemenu.cpp
             KFileItem fileItem(url);
@@ -166,6 +188,9 @@ void KateProjectTreeViewContextMenu::exec(const QString &filename, const QModelI
             dlg->setAttribute(Qt::WA_DeleteOnClose);
             dlg->show();
         } else if (rename && action == rename) {
+            if (!index.isValid()) {
+                return;
+            }
             /**
              * hack:
              * We store a reference to project in the item so that
@@ -182,12 +207,12 @@ void KateProjectTreeViewContextMenu::exec(const QString &filename, const QModelI
         } else if (action == fileHistory) {
             FileHistory::showFileHistory(index.data(Qt::UserRole).toString());
         } else if (addFile && action == addFile) {
-            QString name = getName(parent);
+            QString name = getName(parent, i18n("New File"));
             if (!name.isEmpty()) {
                 parent->addFile(index, name);
             }
         } else if (addFolder && action == addFolder) {
-            QString name = getName(parent);
+            QString name = getName(parent, i18n("New Folder"));
             if (!name.isEmpty()) {
                 parent->addDirectory(index, name);
             }
