@@ -9,10 +9,10 @@
 #include "kateprojectindex.h"
 #include "kateprojectitem.h"
 
+#include "hostprocess.h"
 #include <bytearraysplitter.h>
 #include <gitprocess.h>
 
-#include "hostprocess.h"
 #include <QDir>
 #include <QDirIterator>
 #include <QFile>
@@ -24,6 +24,8 @@
 #include <QThread>
 #include <QtConcurrent>
 
+#include <KLocalizedString>
+
 #include <algorithm>
 #include <tuple>
 #include <vector>
@@ -116,7 +118,7 @@ void KateProjectWorker::loadProject(QStandardItem *parent, const QVariantMap &pr
         /**
          * recurse
          */
-        QStandardItem *subProjectItem = new KateProjectItem(KateProjectItem::Project, subProject[keyName].toString());
+        QStandardItem *subProjectItem = new KateProjectItem(KateProjectItem::Project, subProject[keyName].toString(), QString());
         loadProject(subProjectItem, subProject, file2Item, baseDir);
         parent->appendRow(subProjectItem);
     }
@@ -164,8 +166,7 @@ QStandardItem *KateProjectWorker::directoryParent(const QDir &base, QHash<QStrin
      * simple, no recursion, append new item toplevel
      */
     if (slashIndex < 0) {
-        const auto item = new KateProjectItem(KateProjectItem::Directory, path);
-        item->setData(base.absoluteFilePath(path), Qt::UserRole);
+        const auto item = new KateProjectItem(KateProjectItem::Directory, path, base.absoluteFilePath(path));
         dir2Item[path] = item;
         dir2Item[QString()]->appendRow(item);
         return item;
@@ -187,8 +188,7 @@ QStandardItem *KateProjectWorker::directoryParent(const QDir &base, QHash<QStrin
     /**
      * else: recurse on left side
      */
-    const auto item = new KateProjectItem(KateProjectItem::Directory, rightPart);
-    item->setData(base.absoluteFilePath(path), Qt::UserRole);
+    const auto item = new KateProjectItem(KateProjectItem::Directory, rightPart, base.absoluteFilePath(path));
     dir2Item[path] = item;
     directoryParent(base, dir2Item, leftPart)->appendRow(item);
     return item;
@@ -261,8 +261,7 @@ void KateProjectWorker::loadFilesEntry(QStandardItem *parent,
              * construct the item with right directory prefix
              * already hang in directories in tree
              */
-            KateProjectItem *fileItem = new KateProjectItem(KateProjectItem::LinkedProject, fileName);
-            fileItem->setData(filePath, Qt::UserRole);
+            KateProjectItem *fileItem = new KateProjectItem(KateProjectItem::LinkedProject, fileName, filePath);
 
             /**
              * projects are directories, register them, we walk in order over the projects
@@ -292,7 +291,10 @@ void KateProjectWorker::loadFilesEntry(QStandardItem *parent,
      */
     const QList<QString> files = findFiles(dir, filesEntry);
 
-    QStringList excludeFolderPatterns = m_projectMap.value(QStringLiteral("exclude_patterns")).toStringList();
+    /**
+     * precompute regex to exclude stuff for the worker threads
+     */
+    const QStringList excludeFolderPatterns = m_projectMap.value(QStringLiteral("exclude_patterns")).toStringList();
     std::vector<QRegularExpression> excludeRegexps;
     excludeRegexps.reserve(excludeFolderPatterns.size());
     for (const auto &pattern : excludeFolderPatterns) {
@@ -334,13 +336,9 @@ void KateProjectWorker::loadFilesEntry(QStandardItem *parent,
          * construct the item with info about filename + full file path
          */
         if (info.isFile()) {
-            projectItem = new KateProjectItem(KateProjectItem::File, fileName);
-            projectItem->setData(fullFilePath, Qt::UserRole);
-        }
-        else if(info.isDir() && QDir(fullFilePath).isEmpty())
-        {
-            projectItem = new KateProjectItem(KateProjectItem::Directory, fileName);
-            projectItem->setData(fullFilePath, Qt::UserRole);
+            projectItem = new KateProjectItem(KateProjectItem::File, fileName, fullFilePath);
+        } else if (info.isDir() && QDir(fullFilePath).isEmpty()) {
+            projectItem = new KateProjectItem(KateProjectItem::Directory, fileName, fullFilePath);
         }
     });
 
@@ -471,6 +469,11 @@ QList<QString> KateProjectWorker::filesFromGit(const QDir &dir, bool recursive)
         lsFilesUntrackedArgs.insert(4, QStringLiteral("--deduplicate"));
     }
 
+    if (major == -1) {
+        Q_EMIT errorOccurred(notInstalledErrorString(QStringLiteral("'git'")));
+        return {};
+    }
+
     // ls-files + ls-files untracked
     return gitFiles(dir, recursive, lsFilesArgs) << gitFiles(dir, recursive, lsFilesUntrackedArgs);
 }
@@ -506,6 +509,7 @@ QList<QString> KateProjectWorker::filesFromMercurial(const QDir &dir, bool recur
     QList<QString> files;
     static const auto fullExecutablePath = safeExecutableName(QStringLiteral("hg"));
     if (fullExecutablePath.isEmpty()) {
+        Q_EMIT errorOccurred(notInstalledErrorString(QStringLiteral("'hg'")));
         return files;
     }
 
@@ -538,6 +542,7 @@ QList<QString> KateProjectWorker::filesFromSubversion(const QDir &dir, bool recu
     QList<QString> files;
     static const auto fullExecutablePath = safeExecutableName(QStringLiteral("svn"));
     if (fullExecutablePath.isEmpty()) {
+        Q_EMIT errorOccurred(notInstalledErrorString(QStringLiteral("'svn'")));
         return files;
     }
 
@@ -605,6 +610,7 @@ QList<QString> KateProjectWorker::filesFromDarcs(const QDir &dir, bool recursive
     QList<QString> files;
     static const auto fullExecutablePath = safeExecutableName(QStringLiteral("darcs"));
     if (fullExecutablePath.isEmpty()) {
+        Q_EMIT errorOccurred(notInstalledErrorString(QStringLiteral("'darcs'")));
         return files;
     }
 
@@ -622,7 +628,7 @@ QList<QString> KateProjectWorker::filesFromDarcs(const QDir &dir, bool recursive
         }
 
         auto str = QString::fromLocal8Bit(darcs.readAllStandardOutput());
-        QRegularExpression exp(QStringLiteral("Root: ([^\\n\\r]*)"));
+        static const QRegularExpression exp(QStringLiteral("Root: ([^\\n\\r]*)"));
         auto match = exp.match(str);
 
         if (!match.hasMatch()) {
@@ -649,7 +655,7 @@ QList<QString> KateProjectWorker::filesFromDarcs(const QDir &dir, bool recursive
     }
 
     files.reserve(relFiles.size());
-    for (const QString &relFile : qAsConst(relFiles)) {
+    for (const QString &relFile : std::as_const(relFiles)) {
         const QString path = dir.relativeFilePath(root + QLatin1String("/") + relFile);
 
         if ((!recursive && (relFile.indexOf(QLatin1Char('/')) != -1)) || (recursive && (relFile.indexOf(QLatin1String("..")) == 0))) {
@@ -668,6 +674,7 @@ QList<QString> KateProjectWorker::filesFromFossil(const QDir &dir, bool recursiv
     QList<QString> files;
     static const auto fullExecutablePath = safeExecutableName(QStringLiteral("fossil"));
     if (fullExecutablePath.isEmpty()) {
+        Q_EMIT errorOccurred(notInstalledErrorString(QStringLiteral("'fossil'")));
         return files;
     }
 
@@ -700,8 +707,10 @@ QList<QString> KateProjectWorker::filesFromDirectory(QDir dir, bool recursive, b
      * setup our filters
      */
     QDir::Filters filterFlags = QDir::Files | QDir::Dirs | QDir::NoDot | QDir::NoDotDot;
-    if(hidden)
+    if (hidden) {
         filterFlags |= QDir::Hidden;
+    }
+
     dir.setFilter(filterFlags);
     if (!filters.isEmpty()) {
         dir.setNameFilters(filters);
@@ -716,7 +725,7 @@ QList<QString> KateProjectWorker::filesFromDirectory(QDir dir, bool recursive, b
     }
 
     /**
-     * create iterator and collect all files
+     * trigger potential recursive directory search
      */
     QList<QString> files;
     QDirIterator dirIterator(dir, flags);
@@ -729,4 +738,12 @@ QList<QString> KateProjectWorker::filesFromDirectory(QDir dir, bool recursive, b
     return files;
 }
 
+QString KateProjectWorker::notInstalledErrorString(const QString &program)
+{
+    return i18n(
+        "Unable to load %1 based project because either %1 is not installed or it wasn't found in PATH environment variable. Please install %1 or "
+        "alternatively disable the option 'Autoload Repositories && Build Trees' in project settings.",
+        program);
+}
+
 #include "moc_kateprojectworker.cpp"
