@@ -37,7 +37,7 @@
 
 K_PLUGIN_FACTORY_WITH_JSON(TextFilterPluginFactory, "textfilterplugin.json", registerPlugin<PluginKateTextFilter>();)
 
-PluginKateTextFilter::PluginKateTextFilter(QObject *parent, const QList<QVariant> &)
+PluginKateTextFilter::PluginKateTextFilter(QObject *parent, const QVariantList &)
     : KTextEditor::Plugin(parent)
 {
     // register command
@@ -138,6 +138,10 @@ static void slipInFilter(KProcess &proc, KTextEditor::View &view, const QString
     proc.setShellCommand(command);
 
     proc.start();
+    if (!proc.waitForStarted(4000)) {
+        KMessageBox::error(nullptr, i18n("Failed to start process"));
+        return;
+    }
     QByteArray encoded = inputText.toLocal8Bit();
     proc.write(encoded);
     proc.closeWriteChannel();
@@ -278,5 +282,3 @@ PluginViewKateTextFilter::~PluginViewKateTextFilter()
 
 // required for TextFilterPluginFactory vtable
 #include "plugin_katetextfilter.moc"
-
-#include "moc_plugin_katetextfilter.cpp"
