@@ -27,7 +27,6 @@ class QCheckBox;
 class QComboBox;
 class QSpinBox;
 class KateMainWindow;
-class KPluralHandlingSpinBox;
 
 struct PluginPageListItem {
     KTextEditor::Plugin *plugin;
@@ -101,7 +100,9 @@ private:
     QComboBox *m_diffStyle = nullptr;
     QCheckBox *m_urlBarShowSymbols = nullptr;
     QCheckBox *m_openNewTabInFrontOfCurrent = nullptr;
+    QCheckBox *m_cycleThroughTabs = nullptr;
     QSpinBox *m_diagnosticsLimit = nullptr;
+    QCheckBox *m_hintViewEnabled = nullptr;
 
     Ui::SessionConfigWidget sessionConfigUi;
 
